Madlag 3DWare
==========================

This package contain various solidpython/openscad designs like raspberry pi case elements, specific robot parts.

You can install it by :

.. code-block:: 
pip install madlag3dware

Credits
-------

- `Distribute`_
- `Buildout`_
- `modern-package-template`_

.. _Buildout: http://www.buildout.org/
.. _Distribute: http://pypi.python.org/pypi/distribute
.. _`modern-package-template`: http://pypi.python.org/pypi/modern-package-template
